
model{
  
  #likelihood
  for (i in 1:n.Area){
    for(j in 1:n.Area){
      
      #movement: process model (zero-inflated)
      N[i,j] ~ dpois(eff.lambda[i,j])
      w[i,j]~dbern(psi)
      eff.lambda[i,j]<- w[i,j]*lambda[i,j]
      log(lambda[i,j]) <- alpha.y + I.a[Area[j]] + beta1*dist[i,j]+beta2*area[j]
      
      #movement: observation model
      p.m[i,j]~ dbeta(p.m.alpha[i,j],p.m.beta[i,j])
      y[i,j] ~ dbin(p.m[i,j],N[i,j])
      
      #process model for breeding probability|movement
      N.bp[i,j] ~ dbin(s.p[i,j],N[i,j])
      logit(s.p[i,j])<-alpha.bp+ I.b[Area[j]] +beta.s1*dist[i,j]+beta.s2*pow(dist[i,j],2)+beta.s3*area[j]
      
      #observation model for breeding probability|movement
      p.n[i,j]~dbeta(p.n.alpha[i],p.n.beta[i])
      y.bp[i,j] ~ dbin(p.n[i,j],N.bp[i,j])
      
      #process model for successful reproduction | movement 
      N.s[i,j] ~ dbin(t.p[i,j],N.bp[i,j])  
      logit(t.p[i,j])<-alpha.ns+I.c[Area[j]] +beta.t1*dist[i,j]+beta.t2*area[j]
      y.s[i,j]~dbin(p.n[i,j],N.s[i,j])
      
      #derived networks for dispersal and effective dispersal
      disperse[i,j]<-s.p[i,j]*eff.lambda[i,j] 
      eff.disperse[i,j]<-t.p[i,j]*s.p[i,j]*eff.lambda[i,j] 

    }
  }
  
  
#priors for fixed effects
  alpha.y ~ dnorm(0,0.001)
  beta1 ~ dnorm(0,0.001)
  beta2 ~ dnorm(0,0.001)
  alpha.bp ~ dnorm(0,0.001)
  beta.s1 ~ dnorm(0,0.001)
  beta.s2 ~ dnorm(0,0.001)
  beta.s3 ~ dnorm(0,0.001)
  alpha.ns ~ dnorm(0,0.001)
  beta.t1 ~ dnorm(0,0.001)
  beta.t2 ~ dnorm(0,0.001)
      psi ~ dunif(0,1)
  
  
 
  #priors/hyperpriors for random effects
  for (i in 1:n.Area){    
    I.a[i] ~ dnorm(0, tau.i.a)	
    I.b[i] ~ dnorm(0, tau.i.b)	
    I.c[i] ~ dnorm(0, tau.i.c)	
  }
  
  tau.i.a <- 1 / (sigma.i.a * sigma.i.a)
  sigma.i.a ~ dunif(0, 10)
  
  tau.i.b <- 1 / (sigma.i.b * sigma.i.b)
  sigma.i.b ~ dunif(0, 10)
  
  tau.i.c <- 1 / (sigma.i.c * sigma.i.c)
  sigma.i.c ~ dunif(0, 10)
  
  }

