
#set working directory (where the "jags_data.rds" and "jags_code_effective_connectivity.R" files are saved)
setwd("")

#load data
jags.data<- readRDS("jags_data.rds")
#y is a site x site matrix for movement resights
#y.bp is a site x site matrix for dispersal resights
#y.s is a site x site matrix for effective dispersal resights
#area contains the mean-centered area for each site (square km)(log-transformed) 
#dist is a site x site matrix with the mean-centered distances (in km)(log-transformed) between sites
#Area contains the site labels (1-27)
#n.Area is the total number of sites (27)
#p.n.alpha contains a site x site matrix with shape1 parameters (for beta distribution) for informed priors for nest detectability
#p.n.beta  contains a site x site matrix with shape2 parameters (for beta distribution) for informed priors for nest detectability
#p.m.alpha contains a site x site matrix with shape1 parameters (for beta distribution) for informed priors for movement detectability
#p.m.beta  contains a site x site matrix with shape2 parameters (for beta distribution) for informed priors for movement detectability

#set initial values
N.bp= matrix(212,nrow = jags.data$n.Area,ncol = jags.data$n.Area)
N = matrix(212,nrow = jags.data$n.Area,ncol = jags.data$n.Area)
N.s = matrix(212,nrow = jags.data$n.Area,ncol = jags.data$n.Area)
p.n=matrix(0.95,nrow = jags.data$n.Area,ncol = jags.data$n.Area)
w = matrix(1,nrow = jags.data$n.Area,ncol = jags.data$n.Area)
inits<-function(){
  list(
    I.a=rnorm(jags.data$n.Area),N.bp=N.bp,N=N,N.s=N.s,w=w,p.n=p.n)
}

# MCMC settings 
ni <- 150000 
nt <- 50    
nb <- 5000
nc <- 3


#set parameters to monitor
params=c("alpha.y","beta1","beta2","alpha.bp","beta.s1","beta.s2","beta.s3",
         "alpha.ns","beta.t1","beta.t2","psi","eff.lambda","disperse","eff.disperse","t.p","s.p","sigma.i.a","sigma.i.b","sigma.i.c")

#load jagsUI package
library(jagsUI)

#run model
model=jags(model.file="jags_code_effective_connectivity.R",
           parameters.to.save=params,data=jags.data,inits=inits,n.chains=nc,n.burnin=nb,n.iter=ni,n.thin=nt,DIC=TRUE)

#note that connectivity metrics were calculated from estimates of "eff.lambda","disperse", and "eff.disperse" using the igraph package